######################################################
# R script for assignment on segregation / homophily #
######################################################

# load RSiena commands:
library(RSiena)

# set working directory to where the data are:
setwd("<type your directory name of choice here>")   
list.files()

# read the data sets for the assignment:
friendship.net1 <- as.matrix(read.table("klas03e-friends-waveA.dat",na.strings="9"))
friendship.net2 <- as.matrix(read.table("klas03e-friends-waveB.dat",na.strings="9"))
friendship.net3 <- as.matrix(read.table("klas03e-friends-waveC.dat",na.strings="9"))
friendship.net4 <- as.matrix(read.table("klas03e-friends-waveD.dat",na.strings="9"))
primary.net <- as.matrix(read.table("klas03e-primary.dat",na.strings="9"))
demographics <- as.matrix(read.table("klas03e-demographics.dat",na.strings="0"))
# The "na.string" option identifies missing data codes.
# Actually, class 03e does not contain much missing data. This is different
# for other classroom data from Knecht's study, which we will be addressing
# in other exercises.

# find out number of actors in data sets:
numberActors <- dim(demographics)[1]
numberActors

# identify dependent variable for the analysis:
friendship <- sienaNet(array(c(friendship.net1,friendship.net2,
  friendship.net3,friendship.net4),dim=c(numberActors,numberActors,4)))

# identify covariates for the analysis:
sex.M <- coCovar(demographics[,1])
primary <- coDyadCovar(primary.net)

# combine data for the analysis:
segregationdata <- sienaDataCreate(friendship,sex.M,primary)

# get effects table for model specification:
segregationeffects <- getEffects(segregationdata)

# generate initial descriptive outputfile:
print01Report(segregationdata,segregationeffects,
  modelname='segregation.descriptive')

# which effects are available?
fix(segregationeffects)
# Take a thorough look at the 'shortName' column, as it contains the
# names by which you can identify effects in a script!
# ((please close the screen with the effects object again))

# which effects are already chosen?
segregationeffects
# rate parameters, outdegree and reciprocity are included by default.

# select effects for the first model (and first DEselect 'reciprocity'):
segregationeffects <- setEffect(segregationeffects,recip,type='eval',include=FALSE)
segregationeffects <- includeEffects(segregationeffects,X,interaction1='primary')
segregationeffects <- includeEffects(segregationeffects,egoX,altX,sameX,interaction1='sex.M')
# the selection can also be done interactively by calling fix(segregationeffects)

# create first model for estimation:
first.model <- sienaModelCreate(useStdInits=TRUE,projname='segregation.first',
  cond=FALSE)
# the last option 'cond=FALSE' switches to unconditional moment estimation,
# i.e., lets rate parameters be estimated instead of conditioning on the
# observed number of changes between networks.

# estimate first model:
first.results <- siena07(first.model,data=segregationdata, 
  effects=segregationeffects,batch=FALSE,verbose=FALSE)
# Results are written to file "segregation.first.out" in the working directory.
# The main ingredients can be seen by calling the results object:
first.results

# If estimation results should not show sufficient convergence, another run
# with better starting values may help. The following lines of code turn off the
# default option of using standard initial values; instead, the last available
# estimates will be used as starting values:
first.model$useStdInits=FALSE
first.results <- siena07(first.model,data=segregationdata, 
  effects=segregationeffects,batch=FALSE,verbose=FALSE,prevAns=first.results)
# The difference to the previous estimation run is in the added 'prevAns' option.
first.results
# Convergence statistics should have improved. Note that new results will be
# appended to the existing file "segregation.first.out", so scroll down for latest
# estimates.

# Now re-include reciprocity effect for second model:
segregationeffects <- includeEffects(segregationeffects,recip)
segregationeffects

# create second model for estimation:
second.model <- sienaModelCreate(useStdInits=FALSE,projname='segregation.second',
  cond=FALSE)

# estimate second model:
second.results <- siena07(second.model,data=segregationdata, 
  effects=segregationeffects,batch=FALSE,verbose=FALSE)
# Results are written to file "segregation.second.out" in the working directory.
second.results

# include triadic effects for third model:
segregationeffects <- includeEffects(segregationeffects,transTrip,transTies,cycle3)
segregationeffects

# create third model for estimation:
third.model <- sienaModelCreate(useStdInits=FALSE,projname='segregation.third',
  cond=FALSE)

# estimate third model:
third.results <- siena07(third.model,data=segregationdata, 
  effects=segregationeffects,batch=FALSE,verbose=FALSE)
# Results are written to file "segregation.third.out" in the working directory.
third.results

# If you look at the sequence of results, you see the effect size of 'same sex.M'
# drop, the more structural control parameters are included. When comparing
# the first and the third model, there even is a significant difference in model
# results: 95% confidence intervals for this parameter, which can be constructed
# with the help of the standard error estimates, do not overlap!
